@@ -1,4 +1,6 @@
-"""Reading and writing from KlustaKwik-format files.
+# -*- coding: utf-8 -*-
+"""
+Reading and writing from KlustaKwik-format files.
 Ref: http://klusters.sourceforge.net/UserManual/data-files.html
 
 Supported : Read, Write
@@ -12,16 +14,28 @@ weren't set. Consider removing those annotations if they are redundant.
 * Load features in addition to spiketimes.
 """
 
-# I need to subclass BaseIO
-from .baseio import BaseIO
-
-# to import : Block, Segment, AnalogSignal, SpikeTrain, SpikeTrainList
-from ..core import *
-from .tools import create_many_to_one_relationship
+import glob
+import logging
+import os.path
+import shutil
 
 # note neo.core need only numpy and quantitie
 import numpy as np
-import quantities as pq
+try:
+    import matplotlib.mlab as mlab
+except ImportError as err:
+    HAVE_MLAB = False
+    MLAB_ERR = err
+else:
+    HAVE_MLAB = True
+    MLAB_ERR = None
+
+
+# I need to subclass BaseIO
+from neo.io.baseio import BaseIO
+
+from neo.core import Block, Segment, Unit, SpikeTrain
+from neo.io.tools import create_many_to_one_relationship
 
 # Pasted version of feature file format spec
 """
@@ -52,13 +66,6 @@ of the recording session.
 Notice that the last line must end with a newline or carriage return.
 """
 
-import numpy as np
-import glob
-import matplotlib.mlab as mlab
-import os.path
-import shutil
-import logging
-
 
 class KlustaKwikIO(BaseIO):
     """Reading and writing from KlustaKwik-format files."""
@@ -100,6 +107,8 @@ class KlustaKwikIO(BaseIO):
         sampling_rate : in Hz, necessary because the KlustaKwik files
             stores data in samples.
         """
+        if not HAVE_MLAB:
+            raise MLAB_ERR
         BaseIO.__init__(self)
         #self.filename = os.path.normpath(filename)
         self.filename, self.basename = os.path.split(os.path.abspath(filename))
@@ -308,7 +317,7 @@ class KlustaKwikIO(BaseIO):
                 except KeyError:
                     # Use empty
                     all_features = [
-                        [] for n in range(len(spike_times_in_samples))]
+                        [] for _ in range(len(spike_times_in_samples))]
                 all_features = np.asarray(all_features)
                 if all_features.ndim != 2:
                     raise ValueError("waveform features should be 2d array")
