@@ -1,4 +1,4 @@
-# encoding: utf-8
+# -*- coding: utf-8 -*-
 """
 Class for reading/writing data in a raw binary interleaved compact file.
 Sampling rate, units, number of channel and dtype must be externally known.
@@ -11,13 +11,15 @@ Author: sgarcia
 
 """
 
-from .baseio import BaseIO
-from ..core import *
-from .tools import create_many_to_one_relationship
+import os
 
 import numpy as np
 import quantities as pq
-import os
+
+from neo.io.baseio import BaseIO
+from neo.core import Segment, AnalogSignal
+from neo.io.tools import create_many_to_one_relationship
+
 
 class RawBinarySignalIO(BaseIO):
     """
@@ -45,14 +47,16 @@ class RawBinarySignalIO(BaseIO):
                                         ('nbchannel' , { 'value' : 16 } ),
                                         ('bytesoffset' , { 'value' : 0 } ),
                                         ('t_start' , { 'value' : 0. } ),
-                                        ('dtype' , { 'value' : 'f4' , 'possible' : ['f4' , 'i2' , 'i4' , 'f8' ] } ),
+                                        ('dtype' , { 'value' : 'float32' , 'possible' : ['float32' , 'float64',
+                                                                                                'int16' , 'uint16', 'int32' , 'uint32',  ] } ),
                                         ('rangemin' , { 'value' : -10 } ),
                                         ('rangemax' , { 'value' : 10 } ),
                                     ]
                         }
     write_params       = { Segment : [
                                         ('bytesoffset' , { 'value' : 0 } ),
-                                        ('dtype' , { 'value' : 'f4' , 'possible' : ['f4' , 'i2' , 'i4' , 'f8' ] } ),
+                                        ('dtype' , { 'value' : 'float32' , 'possible' :  ['float32' , 'float64',
+                                                                                                    'int16' , 'uint16', 'int32' , 'uint32',  ] } ),
                                         ('rangemin' , { 'value' : -10 } ),
                                         ('rangemax' , { 'value' : 10 } ),
                                     ]
@@ -120,28 +124,31 @@ class RawBinarySignalIO(BaseIO):
         unit = pq.Quantity(1, unit)
 
         if not lazy:
-            f = open(self.filename , 'rb')
-            buf = f.read()
-            f.close()
-            sig = np.fromstring(buf[bytesoffset:], dtype = dtype )
-
+            sig = np.memmap(self.filename, dtype = dtype, mode = 'r', offset = bytesoffset)
             if sig.size % nbchannel != 0 :
                 sig = sig[:- sig.size%nbchannel]
             sig = sig.reshape((sig.size/nbchannel,nbchannel))
-
             if dtype.kind == 'i' :
                 sig = sig.astype('f')
-                sig /= 2**(8*dtype.itemsize-1)
+                sig /= 2**(8*dtype.itemsize)
                 sig *= ( rangemax-rangemin )
-
+                sig += ( rangemax+rangemin )/2.
+            elif dtype.kind == 'u' :
+                sig = sig.astype('f')
+                sig /= 2**(8*dtype.itemsize)
+                sig *= ( rangemax-rangemin )
+                sig += rangemin
+            sig_with_units =  pq.Quantity(sig, units=unit, copy = False)
+        
         for i in range(nbchannel) :
             if lazy:
                 signal = [ ]*unit
             else:
-                signal = pq.Quantity(sig[:,i], units=unit)
+                signal = sig_with_units[:,i]
 
             anaSig = AnalogSignal(signal, sampling_rate=sampling_rate,
-                                  t_start=t_start, channel_index=i)
+                                  t_start=t_start, channel_index=i, copy = False)
+            
             if lazy:
                 # TODO
                 anaSig.lazy_shape = None
@@ -150,12 +157,8 @@ class RawBinarySignalIO(BaseIO):
         create_many_to_one_relationship(seg)
         return seg
 
-    def write_segment(self, segment,
-                                dtype = 'f4',
-                                rangemin = -10,
-                                rangemax = 10,
-                                bytesoffset = 0,
-                            ):
+    def write_segment(self, segment, dtype='f4', rangemin=-10,
+                      rangemax=10, bytesoffset=0):
         """
 
          **Arguments**
@@ -165,6 +168,9 @@ class RawBinarySignalIO(BaseIO):
             rangemin , rangemax : if the dtype is integer, range can give in volt the min and the max of the range
 
         """
+        if bytesoffset:
+            raise NotImplementedError('bytesoffset values other than 0 ' +
+                                      'not supported')
 
         dtype = np.dtype(dtype)
 
@@ -172,18 +178,22 @@ class RawBinarySignalIO(BaseIO):
         for anasig in segment.analogsignals[1:]:
             assert anasig.size == segment.analogsignals[0].size
 
-        sigs = np.empty( (segment._analogsignals[0].size, len(segment._analogsignals)) )
-        for i,anasig in enumerate(segment.analogsignals):
-            sigs[:,i] = anasig.magnitude
+        sigs = np.empty((segment.analogsignals[0].size, len(segment.analogsignals)))
+        for i, anasig in enumerate(segment.analogsignals):
+            sigs[:, i] = anasig.magnitude
 
-        if dtype.kind == 'i' :
+        if dtype.kind == 'i':
+            sigs -= ( rangemax+rangemin )/2.
             sigs /= (rangemax - rangemin)
-            sigs *= 2**(8*dtype.itemsize-1)
-            sigs = sigs.astype(dtype)
-        else:
-            sigs = sigs.astype(dtype)
-        f = open(self.filename , 'wb')
-        f.write( sigs.tostring() )
+            sigs *= 2 ** (8 * dtype.itemsize )
+        elif dtype.kind == 'u' :
+            sigs -= rangemin
+            sigs /= (rangemax - rangemin)
+            sigs *= 2 ** (8 * dtype.itemsize)
+        sigs = sigs.astype(dtype)
+            
+        f = open(self.filename, 'wb')
+        f.write(sigs.tostring())
         f.close()
 
 
