@@ -1,4 +1,4 @@
-# encoding: utf-8
+# -*- coding: utf-8 -*-
 """
 Classe for reading data in CED spike2 files (.smr).
 
@@ -22,15 +22,15 @@ Author: sgarcia
 
 """
 
-from .baseio import BaseIO
-from ..core import *
-from .tools import create_many_to_one_relationship
+import os
+import sys
 
 import numpy as np
-from numpy import dtype, zeros, fromstring, empty
 import quantities as pq
 
-import os, sys
+from neo.io.baseio import BaseIO
+from neo.core import Segment, AnalogSignal, SpikeTrain, EventArray
+from neo.io.tools import create_many_to_one_relationship
 
 PY3K = (sys.version_info[0] == 3)
 
@@ -59,7 +59,7 @@ class Spike2IO(BaseIO):
 
     has_header         = False
     is_streameable     = False
-    read_params        = {   Segment : [ ], }
+    read_params        = {   Segment : [ ('take_ideal_sampling_rate' , { 'value' : False })] }
     write_params       = None
 
     name               = 'Spike 2 CED'
@@ -78,6 +78,7 @@ class Spike2IO(BaseIO):
         self.filename = filename
 
     def read_segment(self ,
+                                            take_ideal_sampling_rate = False,
                                             lazy = False,
                                             cascade = True,
 
@@ -118,10 +119,11 @@ class Spike2IO(BaseIO):
 
             if channelHeader.kind in [1, 9]:
                 #~ print 'analogChanel'
-                anaSigs = self.readOneChannelContinuous( fid, i, header ,lazy = lazy)
+                anaSigs = self.readOneChannelContinuous( fid, i, header, take_ideal_sampling_rate, lazy = lazy)
                 #~ print 'nb sigs', len(anaSigs) , ' sizes : ',
                 for anaSig in anaSigs :
                     addannotations(anaSig, channelHeader)
+                    anaSig.name = str(anaSig.annotations['title'])
                     seg.analogsignals.append( anaSig )
                     #~ print sig.signal.size,
                 #~ print ''
@@ -147,7 +149,7 @@ class Spike2IO(BaseIO):
     def read_header(self , filename = ''):
 
         fid = open(filename, 'rb')
-        header = HeaderReader(fid,   dtype(headerDescription))
+        header = HeaderReader(fid,   np.dtype(headerDescription))
         #~ print 'chan_size' , header.chan_size
 
 
@@ -160,31 +162,32 @@ class Spike2IO(BaseIO):
         for i in range(header.channels):
             # read global channel header
             fid.seek(512 + 140*i) # TODO verifier i ou i-1
-            channelHeader = HeaderReader(fid, dtype(channelHeaderDesciption1))
+            channelHeader = HeaderReader(fid, np.dtype(channelHeaderDesciption1))
             if channelHeader.kind in [1, 6]:
                 dt = [('scale' , 'f4'),
                       ('offset' , 'f4'),
                       ('unit' , 'S6'),]
-                channelHeader += HeaderReader(fid, dtype(dt))
+                channelHeader += HeaderReader(fid, np.dtype(dt))
                 if header.system_id < 6:
-                    channelHeader += HeaderReader(fid, dtype([ ('divide' , 'i4')]) )#i8
+                    channelHeader += HeaderReader(fid, np.dtype([ ('divide' , 'i4')]) )#i8
                 else :
-                    channelHeader +=HeaderReader(fid, dtype([ ('interleave' , 'i4')]) )#i8
+                    channelHeader +=HeaderReader(fid, np.dtype([ ('interleave' , 'i4')]) )#i8
             if channelHeader.kind in [7, 9]:
                 dt = [('min' , 'f4'),
                       ('max' , 'f4'),
                       ('unit' , 'S6'),]
-                channelHeader += HeaderReader(fid, dtype(dt))
+                channelHeader += HeaderReader(fid, np.dtype(dt))
                 if header.system_id < 6:
-                    channelHeader += HeaderReader(fid, dtype([ ('divide' , 'i4')]))#i8
+                    channelHeader += HeaderReader(fid, np.dtype([ ('divide' , 'i4')]))#i8
                 else :
-                    channelHeader += HeaderReader(fid, dtype([ ('interleave' , 'i4')]) )#i8
+                    channelHeader += HeaderReader(fid, np.dtype([ ('interleave' , 'i4')]) )#i8
             if channelHeader.kind in [4]:
                 dt = [('init_low' , 'u1'),
                       ('next_low' , 'u1'),]
-                channelHeader += HeaderReader(fid, dtype(dt))
+                channelHeader += HeaderReader(fid, np.dtype(dt))
 
             channelHeader.type = dict_kind[channelHeader.kind]
+            #~ print i, channelHeader
             channelHeaders.append(channelHeader)
 
         header.channelHeaders = channelHeaders
@@ -193,11 +196,11 @@ class Spike2IO(BaseIO):
         return header
 
 
-    def readOneChannelContinuous(self , fid, channel_num, header ,lazy = True):
+    def readOneChannelContinuous(self , fid, channel_num, header, take_ideal_sampling_rate, lazy = True):
         # read AnalogSignal
         channelHeader = header.channelHeaders[channel_num]
 
-
+        
         # data type
         if channelHeader.kind == 1:
             dt = np.dtype('i2')
@@ -205,18 +208,22 @@ class Spike2IO(BaseIO):
             dt = np.dtype('f4')
 
         # sample rate
-        if header.system_id in [1,2,3,4,5]: # Before version 5
-            sample_interval = (channelHeader.divide*header.us_per_time*header.time_per_adc)*1e-6
-        else :
-            sample_interval = (channelHeader.l_chan_dvd*header.us_per_time*header.dtime_base)
-        sampling_rate = (1./sample_interval)*pq.Hz
+        if take_ideal_sampling_rate:
+            sampling_rate = channelHeader.ideal_rate*pq.Hz
+        else:
+            if header.system_id in [1,2,3,4,5]: # Before version 5
+                #~ print channel_num, channelHeader.divide, header.us_per_time, header.time_per_adc
+                sample_interval = (channelHeader.divide*header.us_per_time*header.time_per_adc)*1e-6
+            else :
+                sample_interval = (channelHeader.l_chan_dvd*header.us_per_time*header.dtime_base)
+            sampling_rate = (1./sample_interval)*pq.Hz
 
         # read blocks header to preallocate memory by jumping block to block
         fid.seek(channelHeader.firstblock)
         blocksize = [ 0 ]
         starttimes = [ ]
         for b in range(channelHeader.blocks) :
-            blockHeader = HeaderReader(fid, dtype(blockHeaderDesciption))
+            blockHeader = HeaderReader(fid, np.dtype(blockHeaderDesciption))
             if len(blocksize) > len(starttimes):
                 starttimes.append(blockHeader.start_time)
             blocksize[-1] += blockHeader.items
@@ -224,7 +231,7 @@ class Spike2IO(BaseIO):
             if blockHeader.succ_block > 0 :
                 # this is ugly but CED do not garanty continuity in AnalogSignal
                 fid.seek(blockHeader.succ_block)
-                nextBlockHeader = HeaderReader(fid, dtype(blockHeaderDesciption))
+                nextBlockHeader = HeaderReader(fid, np.dtype(blockHeaderDesciption))
                 sample_interval = (blockHeader.end_time-blockHeader.start_time)/(blockHeader.items-1)
                 interval_with_next = nextBlockHeader.start_time - blockHeader.end_time
                 if interval_with_next > sample_interval:
@@ -245,7 +252,7 @@ class Spike2IO(BaseIO):
             if lazy:
                 signal = [ ]*unit
             else:
-                signal = pq.Quantity(empty( bs , dtype = 'f4'), units=unit)
+                signal = pq.Quantity(np.empty( bs , dtype = 'f4'), units=unit)
             anaSig = AnalogSignal(signal,
                                   sampling_rate=sampling_rate,
                                   t_start=(starttimes[b] *
@@ -264,9 +271,9 @@ class Spike2IO(BaseIO):
             pos = 0
             numblock = 0
             for b in range(channelHeader.blocks) :
-                blockHeader = HeaderReader(fid, dtype(blockHeaderDesciption))
+                blockHeader = HeaderReader(fid, np.dtype(blockHeaderDesciption))
                 # read data
-                sig = fromstring( fid.read(blockHeader.items*dt.itemsize) , dtype = dt)
+                sig = np.fromstring( fid.read(blockHeader.items*dt.itemsize) , dtype = dt)
                 anaSigs[numblock][pos:pos+sig.size] = sig.astype('f4')*unit
                 pos += sig.size
                 if pos >= blocksize[numblock] :
@@ -294,27 +301,27 @@ class Spike2IO(BaseIO):
         ## Step 1 : type of blocks
         if channelHeader.kind in [2, 3, 4]:
             # Event data
-            format = [('tick' , 'i4') ]
+            fmt = [('tick' , 'i4') ]
         elif channelHeader.kind in [5]:
             # Marker data
-            format = [('tick' , 'i4') , ('marker' , 'i4') ]
+            fmt = [('tick' , 'i4') , ('marker' , 'i4') ]
         elif channelHeader.kind in [6]:
             # AdcMark data
-            format = [('tick' , 'i4') , ('marker' , 'i4')  , ('adc' , 'S%d' %channelHeader.n_extra   )]
+            fmt = [('tick' , 'i4') , ('marker' , 'i4')  , ('adc' , 'S%d' %channelHeader.n_extra   )]
         elif channelHeader.kind in [7]:
             #  RealMark data
-            format = [('tick' , 'i4') , ('marker' , 'i4')  , ('real' , 'S%d' %channelHeader.n_extra   )]
+            fmt = [('tick' , 'i4') , ('marker' , 'i4')  , ('real' , 'S%d' %channelHeader.n_extra   )]
         elif channelHeader.kind in [8]:
             # TextMark data
-            format = [('tick' , 'i4') , ('marker' , 'i4')  ,  ('label' , 'S%d'%channelHeader.n_extra)]
-        dt = dtype(format)
+            fmt = [('tick' , 'i4') , ('marker' , 'i4')  ,  ('label' , 'S%d'%channelHeader.n_extra)]
+        dt = np.dtype(fmt)
 
 
         ## Step 2 : first read for allocating mem
         fid.seek(channelHeader.firstblock)
         totalitems = 0
-        for b in range(channelHeader.blocks) :
-            blockHeader = HeaderReader(fid, dtype(blockHeaderDesciption))
+        for _ in range(channelHeader.blocks) :
+            blockHeader = HeaderReader(fid, np.dtype(blockHeaderDesciption))
             totalitems += blockHeader.items
             if blockHeader.succ_block > 0 :
                 fid.seek(blockHeader.succ_block)
@@ -334,14 +341,14 @@ class Spike2IO(BaseIO):
                 return sptr
 
         else:
-            alltrigs = zeros( totalitems , dtype = dt)
+            alltrigs = np.zeros( totalitems , dtype = dt)
             ## Step 3 : read
             fid.seek(channelHeader.firstblock)
             pos = 0
-            for b in range(channelHeader.blocks) :
-                blockHeader = HeaderReader(fid, dtype(blockHeaderDesciption))
+            for _ in range(channelHeader.blocks) :
+                blockHeader = HeaderReader(fid, np.dtype(blockHeaderDesciption))
                 # read all events in block
-                trigs = fromstring( fid.read( blockHeader.items*dt.itemsize)  , dtype = dt)
+                trigs = np.fromstring( fid.read( blockHeader.items*dt.itemsize)  , dtype = dt)
 
                 alltrigs[pos:pos+trigs.size] = trigs
                 pos += trigs.size
@@ -368,10 +375,10 @@ class Spike2IO(BaseIO):
 
                 # waveforms
                 if channelHeader.kind == 6 :
-                    waveforms = fromstring(alltrigs['adc'].tostring() , dtype = 'i2')
+                    waveforms = np.fromstring(alltrigs['adc'].tostring() , dtype = 'i2')
                     waveforms = waveforms.astype('f4') *channelHeader.scale/ 6553.6 + channelHeader.offset
                 elif channelHeader.kind == 7 :
-                    waveforms = fromstring(alltrigs['real'].tostring() , dtype = 'f4')
+                    waveforms = np.fromstring(alltrigs['real'].tostring() , dtype = 'f4')
 
 
                 if header.system_id>=6 and channelHeader.interleave>1:
@@ -418,15 +425,15 @@ class HeaderReader(object):
         if fid is not None :
             array = np.fromstring( fid.read(dtype.itemsize) , dtype)[0]
         else :
-            array = zeros( (1) , dtype = dtype)[0]
-        object.__setattr__(self, 'dtype' , dtype)
-        object.__setattr__(self, 'array' , array)
+            array = np.zeros( (1) , dtype = dtype)[0]
+        super(HeaderReader, self).__setattr__('dtype', dtype)
+        super(HeaderReader, self).__setattr__('array', array)
 
     def __setattr__(self, name , val):
         if name in self.dtype.names :
             self.array[name] = val
         else :
-            object.__setattr__(self, name , val)
+            super(HeaderReader, self).__setattr__(name, val)
 
     def __getattr__(self , name):
         #~ print name
@@ -439,8 +446,7 @@ class HeaderReader(object):
                 return self.array[name][1:l+1]
             else:
                 return self.array[name]
-        else :
-            object.__getattr__(self, name )
+
     def names(self):
         return self.array.dtype.names
 
@@ -448,7 +454,8 @@ class HeaderReader(object):
         s = 'HEADER'
         for name in self.dtype.names :
             #~ if self.dtype[name].kind != 'S' :
-                s += name + self.__getattr__(name)
+                #~ s += name + self.__getattr__(name)
+                s += '{}: {}\n'.format(name, getattr(self, name))
         return s
 
 
@@ -460,9 +467,9 @@ class HeaderReader(object):
             newdtype.append( (name , self.dtype[name].str) )
         for name in header2.dtype.names :
             newdtype.append( (name , header2.dtype[name].str) )
-        newdtype = dtype(newdtype)
+        newdtype = np.dtype(newdtype)
         newHeader = HeaderReader(None , newdtype )
-        newHeader.array = fromstring( self.array.tostring()+header2.array.tostring() , newdtype)[0]
+        newHeader.array = np.fromstring( self.array.tostring()+header2.array.tostring() , newdtype)[0]
         return newHeader
 
 # headers structures :
