@@ -12,20 +12,20 @@ Author : sgarcia
 
 """
 
-from .baseio import BaseIO
-from ..core import *
-from .tools import create_many_to_one_relationship
-
-import numpy as np
-from numpy import dtype, zeros, fromstring, empty
-import quantities as pq
-
-import sys
 import os
 import struct
+import sys
+
+import numpy as np
+import quantities as pq
+
+from neo.io.baseio import BaseIO
+from neo.core import Block, Segment, AnalogSignal
+from neo.io.tools import create_many_to_one_relationship
 
 PY3K = (sys.version_info[0] == 3)
 
+
 class WinWcpIO(BaseIO):
     """
     Class for reading from a WinWCP file.
@@ -91,7 +91,7 @@ class WinWcpIO(BaseIO):
             key,val = line.split('=')
             if key in ['NC', 'NR','NBH','NBA','NBD','ADCMAX','NP','NZ', ] :
                 val = int(val)
-            if key in ['AD', 'DT', ] :
+            elif key in ['AD', 'DT', ] :
                 val = val.replace(',','.')
                 val = float(val)
             header[key] = val
@@ -113,7 +113,7 @@ class WinWcpIO(BaseIO):
             NP = NP - NP%header['NC']
             NP = NP/header['NC']
             if not lazy:
-                data = np.memmap(self.filename , dtype('i2')  , 'r',
+                data = np.memmap(self.filename , np.dtype('i2')  , 'r',
                               #shape = (header['NC'], header['NP']) ,
                               shape = (NP,header['NC'], ) ,
                               offset = offset+header['NBA']*SECTORSIZE)
@@ -174,8 +174,8 @@ class HeaderReader():
     def read_f(self, offset =0):
         self.fid.seek(offset)
         d = { }
-        for key, format in self.description :
-            val = struct.unpack(format , self.fid.read(struct.calcsize(format)))
+        for key, fmt in self.description :
+            val = struct.unpack(fmt , self.fid.read(struct.calcsize(fmt)))
             if len(val) == 1:
                 val = val[0]
             else :
