@@ -1,7 +1,9 @@
-# encoding: utf-8
+# -*- coding: utf-8 -*-
 """
-Tests of io.base
+Tests of neo.io.baseio
 """
+
+# needed for python 3 compatibility
 from __future__ import absolute_import, division
 
 try:
@@ -9,21 +11,21 @@ try:
 except ImportError:
     import unittest
 
-from ...core import objectlist
-from ...io.baseio import BaseIO
-import numpy
+from neo.core import objectlist
+from neo.io.baseio import BaseIO
+
 
 class TestIOObjects(unittest.TestCase):
-    
     def test__raise_error_when_not_readable_or_writable(self):
         reader = BaseIO()
         for ob in objectlist:
             if ob not in BaseIO.readable_objects:
-                meth = getattr(reader , 'read_'+ob.__name__.lower() )
+                meth = getattr(reader, 'read_'+ob.__name__.lower())
                 self.assertRaises(AssertionError, meth, )
+
             if ob not in BaseIO.writeable_objects:
-                meth = getattr(reader , 'write_'+ob.__name__.lower() )
-                self.assertRaises(AssertionError, meth, () )
+                meth = getattr(reader, 'write_'+ob.__name__.lower())
+                self.assertRaises(AssertionError, meth, ())
 
 
 if __name__ == "__main__":
